function additionalsets(varargin)
% additionalsets(varargin)
% Usage: This function loads 9 pairs of data sets, uses KK and a filter if checked in the Load data window.
% varargin = {comm}
% The comm structure is the communication factor between the screens.
% comm.path3 = The Path to DataSet3.
% comm.path4 = The Path to DataSet4.
% comm.spath3 = The short Path name to DataSet3.
% comm.spath4 = The short Path name to DataSet4.
% Edit.UserData stores the real path.
% Edit.String stores the short path.
% NOTE:
% comm.dirname is the WORKING dir name.
% comm.path# is the DATA dir name.
% in this function, comm is a GLOBAL variable, because the PBLoadSets returns the paths and changes it.
% Credits: Alex Tesler, Yehu David-Horev, Alon Dana, Maor Asher.
% Modified by: Arthur Doroshev
%--------------------------------------------------------------------------
global comm
if nargin==0
    % Set Default values:
    comm.pos=[240,227,800,550];
    comm.dirname='0';
    comm.name='';
    comm.existingfile='';
    comm.ramp(1:2,1:5)=-1;
    comm.movie=0;
    comm.plot=0;
    comm.UseFilter=0;
    comm.LoadParamaters=0;
    comm.path3='';
    comm.path4='';
    comm.spath3='';
    comm.spath4='';
else
    comm=varargin{1};
end

if all(strcmp(comm.spath3,''))
    comm.path3={'','','','','','','','',''};
    comm.path4={'','','','','','','','',''};
    comm.spath3={'','','','','','','','',''};
    comm.spath4={'','','','','','','','',''};
    comm.dirname2={'','','','','','','','',''};
end

pos=[240,227,1000,600];
comm.name2='';
addsets=figure('Position',pos,'Color','White','MenuBar','none','NumberTitle','off','Name','Impedance Spectroscopy Genetic Programming','Resize','off','Tag','addsets');
if nargin==0
    movegui(addsets,'center');
end

movegui(addsets,'center')
handles=guihandles;
guidata(addsets,handles);

%------------ Buttons: ------------%
% Close:
handles.close=uicontrol('Style','pushbutton','Units','pixels','Parent',addsets,'Position',[10,10,70,25],'FontSize',8,'FontWeight','bold','String','Close');

% Next:
handles.next=uicontrol('Style','pushbutton','Units','pixels','Parent',addsets,'Position',[925,10,70,25],'FontSize',8,'FontWeight','bold','String','Next  >');

%------------ Load Panels: ------------%
Edit1=uipanel('Title','Load','FontSize',10,'Parent',addsets,'Units','pixels','Position',[10,420,325,160],'BackgroundColor','White');

% text: "Enter Data Set 1:"
uicontrol('Style','text','Units','pixels','Parent',Edit1,'Position',[5,120,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 1:');

% text: "Enter Data Set 2:"
uicontrol('Style','text','Units','pixels','Parent',Edit1,'Position',[5,80,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 2:');

% edit 1:
handles.edit1=uicontrol('Style','edit','Units','pixels','Parent',Edit1,'Position',[5,100,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath3{1},'UserData',comm.path3{1},'Tag','edit1');

% edit 2:
handles.edit2=uicontrol('Style','edit','Units','pixels','Parent',Edit1,'Position',[5,60,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath4{1},'UserData',comm.path4{1},'Tag','edit2');

% Browse 1:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit1,'Position',[250,100,70,20],'FontSize',8,'CallBack',{@PBbrowse1,handles},'String','Browse');

% Browse 2:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit1,'Position',[250,60,70,20],'FontSize',8,'CallBack',{@PBbrowse2,handles},'String','Browse');

% Project's Name:
uicontrol('Style','text','Units','pixels','Parent',Edit1,'Position',[5,35,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Name');

% edit Project's Name:
handles.project1=uicontrol('Style','edit','Units','pixels','Parent',Edit1,'Position',[5,15,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.dirname2{1},'Tag','edit 5');
Edit2=uipanel('Title','Load','FontSize',10,'Parent',addsets,'Units','pixels','Position',[10,250,325,160],'BackgroundColor','White');

% text: "Enter Data Set 1:"
uicontrol('Style','text','Units','pixels','Parent',Edit2,'Position',[5,120,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 1:');

% text: "Enter Data Set 2:"
uicontrol('Style','text','Units','pixels','Parent',Edit2,'Position',[5,80,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 2:');

% edit 1:
handles.edit3=uicontrol('Style','edit','Units','pixels','Parent',Edit2,'Position',[5,100,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath3{2},'UserData',comm.path3{2},'Tag','edit1');

% edit 2:
handles.edit4=uicontrol('Style','edit','Units','pixels','Parent',Edit2,'Position',[5,60,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath4{2},'UserData',comm.path4{2},'Tag','edit2');

% Browse 1:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit2,'Position',[250,100,70,20],'FontSize',8,'CallBack',{@PBbrowse3,handles},'String','Browse');

% Browse 2:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit2,'Position',[250,60,70,20],'FontSize',8,'CallBack',{@PBbrowse4,handles},'String','Browse');

% Project's Name
uicontrol('Style','text','Units','pixels','Parent',Edit2,'Position',[5,35,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Name');

% edit Project's Name:
handles.project2=uicontrol('Style','edit','Units','pixels','Parent',Edit2,'Position',[5,15,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.dirname2{2},'Tag','edit 5');
Edit3=uipanel('Title','Load','FontSize',10,'Parent',addsets,'Units','pixels','Position',[10,80,325,160],'BackgroundColor','White');

% text: "Enter Data Set 1:"
uicontrol('Style','text','Units','pixels','Parent',Edit3,'Position',[5,120,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 1:');

% text: "Enter Data Set 2:"
uicontrol('Style','text','Units','pixels','Parent',Edit3,'Position',[5,80,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 2:');

% edit 1:
handles.edit5=uicontrol('Style','edit','Units','pixels','Parent',Edit3,'Position',[5,100,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath3{3},'UserData',comm.path3{3},'Tag','edit1');

% edit 2:
handles.edit6=uicontrol('Style','edit','Units','pixels','Parent',Edit3,'Position',[5,60,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath4{3},'UserData',comm.path4{3},'Tag','edit2');

% Browse 1:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit3,'Position',[250,100,70,20],'FontSize',8,'CallBack',{@PBbrowse5,handles},'String','Browse');

% Browse 2:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit3,'Position',[250,60,70,20],'FontSize',8,'CallBack',{@PBbrowse6,handles},'String','Browse');

% Project's Name:
uicontrol('Style','text','Units','pixels','Parent',Edit3,'Position',[5,35,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Name');

% edit Project's Name:
handles.project3=uicontrol('Style','edit','Units','pixels','Parent',Edit3,'Position',[5,15,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.dirname2{3},'Tag','edit 5');
Edit4=uipanel('Title','Load','FontSize',10,'Parent',addsets,'Units','pixels','Position',[340,420,325,160],'BackgroundColor','White');

% text: "Enter Data Set 1:"
uicontrol('Style','text','Units','pixels','Parent',Edit4,'Position',[5,120,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 1:');

% text: "Enter Data Set 2:"
uicontrol('Style','text','Units','pixels','Parent',Edit4,'Position',[5,80,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 2:');

% edit 1:
handles.edit7=uicontrol('Style','edit','Units','pixels','Parent',Edit4,'Position',[5,100,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath3{4},'UserData',comm.path3{4},'Tag','edit1');

% edit 2:
handles.edit8=uicontrol('Style','edit','Units','pixels','Parent',Edit4,'Position',[5,60,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath4{4},'UserData',comm.path4{4},'Tag','edit2');

% Browse 1:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit4,'Position',[250,100,70,20],'FontSize',8,'CallBack',{@PBbrowse7,handles},'String','Browse');

% Browse 2:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit4,'Position',[250,60,70,20],'FontSize',8,'CallBack',{@PBbrowse8,handles},'String','Browse');

% Project's Name:
uicontrol('Style','text','Units','pixels','Parent',Edit4,'Position',[5,35,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Name');

% edit Project's Name:
handles.project4=uicontrol('Style','edit','Units','pixels','Parent',Edit4,'Position',[5,15,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.dirname2{4},'Tag','edit 5');
Edit5=uipanel('Title','Load','FontSize',10,'Parent',addsets,'Units','pixels','Position',[340 250 325 160],'BackgroundColor','White');

% text: "Enter Data Set 1:"
uicontrol('Style','text','Units','pixels','Parent',Edit5,'Position',[5,120,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 1:');

% text: "Enter Data Set 2:"
uicontrol('Style','text','Units','pixels','Parent',Edit5,'Position',[5,80,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 2:');

% edit 1:
handles.edit9=uicontrol('Style','edit','Units','pixels','Parent',Edit5,'Position',[5,100,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath3{5},'UserData',comm.path3{5},'Tag','edit1');

% edit 2:
handles.edit10=uicontrol('Style','edit','Units','pixels','Parent',Edit5,'Position',[5,60,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath4{5},'UserData',comm.path4{5},'Tag','edit2');

% Browse 1:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit5,'Position',[250,100,70,20],'FontSize',8,'CallBack',{@PBbrowse9,handles},'String','Browse');

% Browse 2:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit5,'Position',[250,60,70,20],'FontSize',8,'CallBack',{@PBbrowse10,handles},'String','Browse');

% Project's Name:
uicontrol('Style','text','Units','pixels','Parent',Edit5,'Position',[5,35,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Name');

% edit Project's Name:
handles.project5=uicontrol('Style','edit','Units','pixels','Parent',Edit5,'Position',[5,15,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.dirname2{5},'Tag','edit 5');
Edit6=uipanel('Title','Load','FontSize',10,'Parent',addsets,'Units','pixels','Position',[340,80,325,160],'BackgroundColor','White');

% text: "Enter Data Set 1:"
uicontrol('Style','text','Units','pixels','Parent',Edit6,'Position',[5,120,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 1:');

% text: "Enter Data Set 2:"
uicontrol('Style','text','Units','pixels','Parent',Edit6,'Position',[5,80,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 2:');

% edit 1
handles.edit11=uicontrol('Style','edit','Units','pixels','Parent',Edit6,'Position',[5,100,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath3{6},'UserData',comm.path3{6},'Tag','edit1');

% edit 2
handles.edit12=uicontrol('Style','edit','Units','pixels','Parent',Edit6,'Position',[5,60,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath4{6},'UserData',comm.path4{6},'Tag','edit2');

% Browse 1:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit6,'Position',[250,100,70,20],'FontSize',8,'CallBack',{@PBbrowse11,handles},'String','Browse');

% Browse 2:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit6,'Position',[250,60,70,20],'FontSize',8,'CallBack',{@PBbrowse12,handles},'String','Browse');

% Project's Name:
uicontrol('Style','text','Units','pixels','Parent',Edit6,'Position',[5,35,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Name');

% edit Project's Name:
handles.project6=uicontrol('Style','edit','Units','pixels','Parent',Edit6,'Position',[5,15,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.dirname2{6},'Tag','edit 5');
Edit7=uipanel('Title','Load','FontSize',10,'Parent',addsets,'Units','pixels','Position',[670,420,325,160],'BackgroundColor','White');

% text: "Enter Data Set 1:"
uicontrol('Style','text','Units','pixels','Parent',Edit7,'Position',[5,120,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 1:');

% text: "Enter Data Set 2:"
uicontrol('Style','text','Units','pixels','Parent',Edit7,'Position',[5,80,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 2:');

% edit 1:
handles.edit13=uicontrol('Style','edit','Units','pixels','Parent',Edit7,'Position',[5,100,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath3{7},'UserData',comm.path3{7},'Tag','edit1');

% edit 2:
handles.edit14=uicontrol('Style','edit','Units','pixels','Parent',Edit7,'Position',[5,60,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath4{7},'UserData',comm.path4{7},'Tag','edit2');

% Browse 1:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit7,'Position',[250,100,70,20],'FontSize',8,'CallBack',{@PBbrowse13,handles},'String','Browse');

% Browse 2:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit7,'Position',[250,60,70,20],'FontSize',8,'CallBack',{@PBbrowse14,handles},'String','Browse');

% Project's Name:
uicontrol('Style','text','Units','pixels','Parent',Edit7,'Position',[5,35,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Name');

% edit Project's Name:
handles.project7=uicontrol('Style','edit','Units','pixels','Parent',Edit7,'Position',[5,15,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.dirname2{7},'Tag','edit 5');
Edit8=uipanel('Title','Load','FontSize',10,'Parent',addsets,'Units','pixels','Position',[670,250,325,160],'BackgroundColor','White');

% text: "Enter Data Set 1:"
uicontrol('Style','text','Units','pixels','Parent',Edit8,'Position',[5,120,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 1:');

% text: "Enter Data Set 2:"
uicontrol('Style','text','Units','pixels','Parent',Edit8,'Position',[5,80,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 2:');

% edit 1:
handles.edit15=uicontrol('Style','edit','Units','pixels','Parent',Edit8,'Position',[5,100,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath3{8},'UserData',comm.path3{8},'Tag','edit1');

% edit 2:
handles.edit16=uicontrol('Style','edit','Units','pixels','Parent',Edit8,'Position',[5,60,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath4{8},'UserData',comm.path4{8},'Tag','edit2');

% Browse 1:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit8,'Position',[250,100,70,20],'FontSize',8,'CallBack',{@PBbrowse15,handles},'String','Browse');

% Browse 2:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit8,'Position',[250,60,70,20],'FontSize',8,'CallBack',{@PBbrowse16,handles},'String','Browse');

% Project's Name:
uicontrol('Style','text','Units','pixels','Parent',Edit8,'Position',[5,35,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Name');

% edit Project's Name:
handles.project8=uicontrol('Style','edit','Units','pixels','Parent',Edit8,'Position',[5,15,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.dirname2{8},'Tag','edit 5');
Edit9=uipanel('Title','Load','FontSize',10,'Parent',addsets,'Units','pixels','Position',[670,80,325,160],'BackgroundColor','White');

% text: "Enter Data Set 1:"
uicontrol('Style','text','Units','pixels','Parent',Edit9,'Position',[5,120,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 1:');

% text: "Enter Data Set 2:"
uicontrol('Style','text','Units','pixels','Parent',Edit9,'Position',[5,80,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 2:');

% edit 1:
handles.edit17=uicontrol('Style','edit','Units','pixels','Parent',Edit9,'Position',[5,100,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath3{9},'UserData',comm.path3{9},'Tag','edit1');

% edit 2:
handles.edit18=uicontrol('Style','edit','Units','pixels','Parent',Edit9,'Position',[5,60,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath4{9},'UserData',comm.path4{9},'Tag','edit2');

% Browse 1:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit9,'Position',[250,100,70,20],'FontSize',8,'CallBack',{@PBbrowse17,handles},'String','Browse');

% Browse 2:
uicontrol('Style','pushbutton','Units','pixels','Parent',Edit9,'Position',[250,60,70,20],'FontSize',8,'CallBack',{@PBbrowse18,handles},'String','Browse');

% Project's Name:
uicontrol('Style','text','Units','pixels','Parent',Edit9,'Position',[5,35,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Name');

% edit Project's Name:
handles.project9=uicontrol('Style','edit','Units','pixels','Parent',Edit9,'Position',[5,15,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.dirname2{9},'Tag','edit 5');

% Define Buttons' Callbacks:
set(handles.close,'CallBack',{@PBClose,handles});
set(handles.next,'CallBack',{@PBNext,handles});
set(handles.project1,'KeyPressFcn',{@Edit1Down,handles});
set(handles.project2,'KeyPressFcn',{@Edit1Down,handles});
set(handles.project3,'KeyPressFcn',{@Edit1Down,handles});
set(handles.project4,'KeyPressFcn',{@Edit1Down,handles});
set(handles.project5,'KeyPressFcn',{@Edit1Down,handles});
set(handles.project6,'KeyPressFcn',{@Edit1Down,handles});
set(handles.project7,'KeyPressFcn',{@Edit1Down,handles});
set(handles.project8,'KeyPressFcn',{@Edit1Down,handles});
set(handles.project9,'KeyPressFcn',{@Edit1Down,handles});

%------------ Functions: ------------%
% Close Button
function PBClose(hObject,eventdata,handles) 
global comm
LoadData(comm)
delete(handles.addsets)

% Next Button
function PBNext(hObject,eventdata,handles) 
global comm
comm.dirname2{1}=get(handles.project1,'String');
comm.dirname2{2}=get(handles.project2,'String');
comm.dirname2{3}=get(handles.project3,'String');
comm.dirname2{4}=get(handles.project4,'String');
comm.dirname2{5}=get(handles.project5,'String');
comm.dirname2{6}=get(handles.project6,'String');
comm.dirname2{7}=get(handles.project7,'String');
comm.dirname2{8}=get(handles.project8,'String');
comm.dirname2{9}=get(handles.project9,'String');
LoadData(comm)
delete(handles.addsets)

% Browse 1 Button
function PBbrowse1(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 1');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit1,'UserData',str1);

    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end
     
    % save the short/full path in String:
    set(handles.edit1,'String',str1);
    comm.path3{1}=str1;
    comm.spath3{1}=str1;
end

% Browse 2 Button
function PBbrowse2(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 2');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit2,'UserData',str1);
   
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end
    % save the short/full path in String:
    set(handles.edit2,'String',str1);
    comm.path4{1}=str1;
    comm.spath4{1}=str1;
end

%Browse 3 Button%
function PBbrowse3(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 1');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit3,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end
    % save the short/full path in String:
    set(handles.edit3,'String',str1);
    comm.path3{2}=str1;
    comm.spath3{2}=str1;
end

% Browse 4 Button
function PBbrowse4(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 2');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit4,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end
    % save the short/full path in String:
    set(handles.edit4,'String',str1);
    comm.path4{2}=str1;
    comm.spath4{2}=str1;
end

%Browse 5 Button%
function PBbrowse5(hObject,eventdata,handles) 
global comm 
[FileName,PathName]=uigetfile('*.*','Load Set 1');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit5,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end

    % save the short/full path in String:
    set(handles.edit5,'String',str1);
    comm.path3{3}=str1;
    comm.spath3{3}=str1;
end

% Browse 6 Button
function PBbrowse6(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 2');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit6,'UserData',str1);
   
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end

    if length(FileName)>30
        str2=FileName;
    end

    % save the short/full path in String:
    set(handles.edit6,'String',str1);
    comm.path4{3}=str1;
    comm.spath4{3}=str1;
end

%Browse 7 Button%
function PBbrowse7(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 1');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit7,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end
    
    % save the short/full path in String:
    set(handles.edit7,'String',str1);
    comm.path3{4}=str1;
    comm.spath3{4}=str1;
end

% Browse 8 Button
function PBbrowse8(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 2');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit8,'UserData',str1);
   
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end

    % save the short/full path in String:
    set(handles.edit8,'String',str1);
    comm.path4{4}=str1;
    comm.spath4{4}=str1;
end

%Browse 9 Button%
function PBbrowse9(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 1');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit9,'UserData',str1);
   
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end
    % save the short/full path in String:
    set(handles.edit9,'String',str1);
    comm.path3{5}=str1;
    comm.spath3{5}=str1;
end

% Browse 10 Button
function PBbrowse10(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 2');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit10,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end

    % save the short/full path in String:
    set(handles.edit10,'String',str1);
    comm.path4{5}=str1;
    comm.spath4{5}=str1;
end

%Browse 11 Button%
function PBbrowse11(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 1');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit11,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end
    % save the short/full path in String:
    set(handles.edit11,'String',str1);
    comm.path3{6}=str1;
    comm.spath3{6}=str1;
end

% Browse 12 Button
function PBbrowse12(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 2');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit12,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end

    % save the short/full path in String:
    set(handles.edit12,'String',str1);
    comm.path4{6}=str1;
    comm.spath4{6}=str1;
end

%Browse 13 Button%
function PBbrowse13(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 1');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit13,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end
    
    % save the short/full path in String:
    set(handles.edit13,'String',str1);
    comm.path3{7}=str1;
    comm.spath3{7}=str1;
end

% Browse 14 Button
function PBbrowse14(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 2');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit14,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end

    % save  the short/full path in String:
    set(handles.edit14,'String',str1);
    comm.path4{7}=str1;
    comm.spath4{7}=str1;
end

%Browse 15 Button%
function PBbrowse15(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 1');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit15,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end
    
    % save the short/full path in String:
    set(handles.edit15,'String',str1);
    comm.path3{8}=str1;
    comm.spath3{8}=str1;
end

% Browse 16 Button
function PBbrowse16(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 2');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit16,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end

    % save the short/full path in String:
    set(handles.edit16,'String',str1);
    comm.path4{8}=str1;
    comm.spath4{8}=str1;
end

%Browse 17 Button%
function PBbrowse17(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 1');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit17,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end
    
    % save the short/full path in String:
    set(handles.edit17,'String',str1);
    comm.path3{9}=str1;
    comm.spath3{9}=str1;
end

% Browse 18 Button
function PBbrowse18(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 2');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit18,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end

    % save the short/full path in String:
    set(handles.edit18,'String',str1);
    comm.path4{9}=str1;
    comm.spath4{9}=str1;
end

% Edit 1 Button Down Function:
function Edit1Down(hObject,eventdata,handles)