% gp_main
% This is the main algorithm, consisting of the following steps:
% (a) Definition of variables, random number generator
% (b) Population initialization: If a seed-file exists, its contents are used for seeding.
% (c) Setting up run-time display, starting with initial population.
% (d) Interating over generations, performing fitness-based selection, and making offsprings by:
%     (i) Mutation = Switch Peak
%     (ii) Add-Peak
%     (iii) Remove-Peak
% (e) Picking best pop_size individuals for next generation
% (f) Updating display.
% Modified by: Arthur Doroshev
%--------------------------------------------------------------------------
% in case of rerun, all work parameters are cleared
clear p pop pop_opt new_pop new_pop_opt fit fit1 fitf fitf1 tr dis dis1
%==================================
rng('shuffle')
%==================================
% (A) DEFINITION OF VARIABLES
%==================================
% Checking if seed model is requested.
% The path for the old popolation is loaded:
name=comm.existingfile;
% a pop was uploaded in case there is a content to the vector loaded
if length(name)>=1
    % make the vector into a string
    name=char(name);
    % load the old data parameters of genes, paramatrized genes & use fitness
    [pp,po,f,ff,disc]=loadolddata(name);
    % pop size by the user is larger than the pop uploaded
    if length(f)<pop_size
        % organize the old population paramrters into correct names
        for i=1:length(f)
            pop{i}=pp{i}; 
            pop_opt{i}=po{i};
            fit(i)=f(i);
            fitf(i)=ff(i);
            dis(i)=disc(i);
            if ~strcmp(par.forcedpick,'') % this repetative 'if' in main.m check if the user chose to force a pick
                pop{i}=Forcedfirst(pop{i});
            end
            % D.C plot data collection
            sseall(i)=dis(i);
            treeall(i)=treecomp(pop{i});
        end
        % pop size by the user is smaller than the pop uploaded
    elseif length(f)<pop_size
        % organize the old population paramrters into correct names
        for i=1:(pop_size-1)
            pop{i}=pp{i};
            pop_opt{i}=po{i};
            fit(i)=f(i);
            fitf(i)=ff(i);
            dis(i)=disc(i);
             if ~strcmp(par.forcedpick,'') % this repetative 'if' in main.m check if the user chose to force a pick
                pop{i}=Forcedfirst(pop{i});
             end
            % D.C plot data collection
            sseall(i)=dis(i);
            treeall(i)=treecomp(pop{i});
        end
            % adding to it
        for i=(length(f)+1):pop_size
            pop{i}=initial(max_trees,fun_set);
            [pop_opt{i},x]=parfit(pop{i},u,y,yr);
            lambda=lentgh(deblank((pop{i})));
            [fit(i),fitf(i),tre(i),dis(i)]=fitness(pop{i},pop_opt{i},u,y,yr,uv,yv,yrv,beta,lambda,FitnessGauss,comm,par,sigmamax);
            % D.C plot data collection
            sseall(i)=dis(i);
            treeall(i)=tre(i);
        end
        % 1 random gene is selected from the rest
        i=pop_size+ceil(rand(1))*(length(f)-pop_size);
        pop{i}=pp{i};
        pop_opt{i}=po{i};
        fit(i)=f(i);
        fitf(i)=ff(i);
        dis(i)=disc(i);
        % D.C plot data collection
        sseall(i)=dis(i);
        treeall(i)=treecomp(pop{i});
        % pop size by the user is same size as the pop uploaded
    else
        % organize the old population paramrters into correct names
        for i=1:(pop_size)
            pop{i}=pp{i};
            pop_opt{i}=po{i};
            fit(i)=f(i);
            fitf(i)=ff(i);
            dis(i)=disc(i);
            if ~strcmp(par.forcedpick,'') % this repetative 'if' in main.m check if the user chose to force a pick
                pop{i}=Forcedfirst(pop{i});
            end
            % D.C plot data collection
            sseall(i)=dis(i);
            treeall(i)=treecomp(pop{i});
        end
    end
% If no seed is supplied, make seed linear.
else
%===============================
% (B) POPULATION INITIALIZATION
%===============================
    pop{1}=initial(max_trees,fun_set);
    if ~strcmp(par.forcedpick,'')  % this repetative 'if' in main.m check if the user chose to force a pick
        pop{1}=Forcedfirst(pop{1});
    end
    % end
    % parametring => pop_opt=the model with paramaters
    %                x=the parameters vector
    [pop_opt{1},x]=parfit(pop{1},u,y,yr);
    % fitness => fit=factor of competability with complexity
    %            fitf=competability
    lambda=length(deblank(pop{1}));
    [fit(1),fitf(1),tre(1),dis(1)]=fitness(pop{1},pop_opt{1},u,y,yr,uv,yv,yrv,beta,lambda,FitnessGauss,comm,par,sigmamax);
    % D.C plot data collection
    sseall(1)=dis(1);
    treeall(1)=tre(1);
    for i=2:pop_size
        % a random gene is generated
        pop{i}=initial(max_trees,fun_set); 
        if ~strcmp(par.forcedpick,'') % this repetative 'if' in main.m check if the user chose to force a pick
            pop{i}=Forcedfirst(pop{i}); 
        end
        % parametring => pop_opt=the model with paramaters
        %                x=the parameters vector
        [pop_opt{i},x]=parfit(pop{i},u,y,yr); 
        % fitness => fit=factor of competability with complexity
        %            fitf=competability
        lambda=length(deblank(pop{i}));
        [fit(i),fitf(i),tre(i),dis(i)]=fitness(pop{i},pop_opt{i},u,y,yr,uv,yv,yrv,beta,lambda,FitnessGauss,comm,par,sigmamax); 
        % D.C plot data collection
        sseall(i)=dis(i);
        treeall(i)=tre(i);
        pop_check=pop;
    end
end
%==================================
% (C) SETTING UP RUN-TIME DISPLAY
%==================================
% taking the best model of the first gen...
[max_fitf,max_fitf_ind]=max(fit);
max_fit_pop=pop_opt{max_fitf_ind};
tau_diff=par.tau_diff;
hh=-(u(2)-u(1))/tau_diff;
t=(-20:hh:20); 
max_fit_pop=strrep(max_fit_pop,'u1','t');
% evaluate the model
ym1=eval(max_fit_pop);
% change the string back
max_fit_pop=strrep(max_fit_pop,'t','u1');
% convolution
[y_r,ym]=int_simpson_matrix(ym1,u,hh);
sse_plt=fitf(max_fitf_ind);
dis_plt=dis(max_fitf_ind);
% checking the complexity of the best model
tr=treecomp(pop{max_fitf_ind});
bestmodel{1}=pop_opt{max_fitf_ind};
bestsse(1)=dis_plt;
besttre(1)=tr;
% sending best model, number of generaion & run number to the interface
plot_model_main1(pop_opt{max_fitf_ind},count_run,y,ym,yr,y_r,u,sse_plt,dis_plt,0,t,yrv,yv,sseall,treeall,bestsse,besttre,handles);
% Counts the number of times the same model is chosen
same_model=pop_opt{max_fitf_ind};
same_model_counter=1;
% movie
if makemovie==1
    set(screen5,'Position',pos)
    movegui(screen5,'center');
    figure(screen5);
    frm(frmcnt)=getframe(figure(screen5));
    frmcnt=frmcnt+1;
    %mov=addframe(mov,frm);
end
%======================================
% (D) ITERATING OVER GENERATIONS
%======================================
count=i+1; % counter for final D.C plot
for i=1:num_gen
    if comm.Abort==0
        [Q,R]=size(pop);
        % A new population of size pop_size is generated by FPS.
        % The new individuals can be generated by either mutation adding or removing a pick.
        j=0;
        while j<pop_size 												
            p_gen=rand(1);
            if p_gen<=p_mutate
                % (i) Mutation = Switch-Pick
                % choose random gene
                fps_num=fps(fit);
                deblank_pop=deblank(pop{fps_num});
                % operate
                pop_swap=swappick(deblank_pop,mut_fun_set);
                i_new=0;
                j=j+1;
                % parametring => pop_swap_opt=the model with paramaters
                %                x=the parameters vector
                if ~strcmp(par.forcedpick,'')
                    pop_swap=Forcedfirst(pop_swap); % this repetative 'if' in main.m check if the user chose to force a pick
                end
                if comm.Abort==0 && sum(strcmp(pop_check,pop_swap))<=p_duplicate
                    [pop_swap_opt,x]=parfit(pop_swap,u,y,yr);
                    lambda=length(deblank(pop_swap));
                    [fit1(j),fitf1(j),tre(j),dis1(j)]=fitness(pop_swap,pop_swap_opt,u,y,yr,uv,yv,yrv,beta,lambda,FitnessGauss,comm,par,sigmamax); 
                    sseall(count)=dis1(j);
                    treeall(count)=tre(j);
                    count=count+1;
                    new_pop{j}=pop_swap; 
                    new_pop_opt{j}=pop_swap_opt; 
                end
            elseif p_gen<=(p_mutate+p_add)
                % (ii) Add pick.
                % choose random gene
                fps_num=fps(fit);
                deblank_pop=deblank(pop{fps_num});
                % operate
                pop_add=addpick(deblank_pop,mut_fun_set);
                i_new=0;
                j=j+1;
                % parametring => pop_add_opt=the model with paramaters
                %                x=the parameters vector
                if ~strcmp(par.forcedpick,'') % this repetative 'if' in main.m check if the user chose to force a pick
                    pop_add=Forcedfirst(pop_add);
                end
                if comm.Abort==0 && sum(strcmp(pop_check,pop_add))<=p_duplicate
                    [pop_add_opt,x]=parfit(pop_add,u,y,yr);
                    lambda=length(deblank(pop_add));
                    [fit1(j),fitf1(j),tre(j),dis1(j)]=fitness(pop_add,pop_add_opt,u,y,yr,uv,yv,yrv,beta,lambda,FitnessGauss,comm,par,sigmamax);
                    sseall(count)=dis1(j);
                    treeall(count)=tre(j);
                    count=count+1;
                    new_pop{j}=pop_add;
                    new_pop_opt{j}=pop_add_opt;
                end
            else
                % (iii) Remove pick.
                % choose random gene
                fps_num=fps(fit);
                deblank_pop=deblank(pop{fps_num});
                % operate
                pop_remove=removepick(deblank_pop,mut_fun_set);
                i_new=0;
                j=j+1;
                % parametring => pop_remove_opt=the model with paramaters
                %                x=the parameters vector
                if ~strcmp(par.forcedpick,'') % this repetative 'if' in main.m check if the user chose to force a pick
                    pop_remove=Forcedfirst(pop_remove);
                end
                if comm.Abort==0 && sum(strcmp(pop_check,pop_remove))<=p_duplicate
                    [pop_remove_opt,x]=parfit(pop_remove,u,y,yr);
                    lambda=length(deblank(pop_remove));
                    [fit1(j),fitf1(j),tre(j),dis1(j)]=fitness(pop_remove,pop_remove_opt,u,y,yr,uv,yv,yrv,beta,lambda,FitnessGauss,comm,par,sigmamax);
                    sseall(count)=dis1(j);
                    treeall(count)=tre(j);
                    count=count+1;
                    new_pop{j}=pop_remove;
                    new_pop_opt{j}=pop_remove_opt;
                end  
            end															
        end																
        % Sort old population and retain top pop_size of them (sorting the population by the punished fitness).
        pop_check=[pop_check,new_pop];
        sort_pop=[new_pop,pop];
        sort_pop_opt=[new_pop_opt,pop_opt];
        sort_fit=[fit1,fit];
        sort_fitf=[fitf1,fitf];
        sort_dis=[dis1,dis];
        for j=1:pop_size-1												
            [max_fit,max_fit_ind]=max(sort_fit);
            pop{j}=sort_pop{max_fit_ind};
            pop_opt{j}=sort_pop_opt{max_fit_ind};
            fit(j)=sort_fit(max_fit_ind);
            fitf(j)=sort_fitf(max_fit_ind);
            dis(j)=sort_dis(max_fit_ind);
            sort_fit(max_fit_ind)=-inf;
        end                                               
        % Last one
        lastpop='';
        for k=1:beta+1
            lastpop=addpick(lastpop,mut_fun_set);
        end
        if ~strcmp(par.forcedpick,'')
            lastpop=Forcedfirst(lastpop); % this repetative 'if' in main.m check if the user chose to force a pick
        end
        pop{pop_size}=lastpop;
        [lastpop_opt,x]=parfit(lastpop,u,y,yr);
        pop_opt{pop_size}=lastpop_opt;
        if comm.Abort==0
            lambda=length(deblank(lastpop));
            [fit(pop_size),fitf(pop_size),tre(pop_size),dis(pop_size)]=fitness(lastpop,lastpop_opt,u,y,yr,uv,yv,yrv,beta,lambda,FitnessGauss,comm,par,sigmamax);
        end
        % sending best model, number of generaion & run number to the interface
        max_fit_pop=pop_opt{1};
        max_fit_pop=strrep(max_fit_pop,'u1','t');
        ym1=eval(max_fit_pop);
        % change back the string
        max_fit_pop=strrep(max_fit_pop,'t','u1');
        if comm.Abort==0
        [y_r,ym]=int_simpson_matrix(ym1,u,hh);
        end
        sse_plt=fitf(1);
        dis_plt=dis(1);
        % checking the complexity of of the best model
        tr=treecomp(pop{1});
        % D.C plot data collection
        bestmodel{i+1}=pop_opt{1};
        bestsse(i+1)=dis_plt; 
        besttre(i+1)=tr;
        % Sending best model, number of generaion & run number to the interface
        % Counts the number of times the same model is chosen
        if strcmp(same_model,pop_opt{1})
        same_model_counter=same_model_counter+1;
        else
            same_model=pop_opt{1};
            same_model_counter=1;
        end
        if same_model_counter==par.stop+1
            plot_model_main2(pop_opt{1},count_run,y,ym,yr,y_r,u,sse_plt,dis_plt,i,t,yrv,yv,sseall,treeall,bestsse,besttre,handles);
            break
        end
        plot_model_main1(pop_opt{1},count_run,y,ym,yr,y_r,u,sse_plt,dis_plt,i,t,yrv,yv,sseall,treeall,bestsse,besttre,handles);
        % movie
        if makemovie==1
            try
               frame=figure(screen5);
               frm(frmcnt)=getframe(figure(screen5));
               frmcnt=frmcnt+1;              
               % mov=addframe(mov,frm);
            catch
                frame=figure(screen5);
                set(screen5,'Position',pos);
                frm(frmcnt)=getframe(figure(screen5));
                frmcnt=frmcnt+1;              
            end
        end
        if i<num_gen												
            % Shuffle population (except at last iteration)
            % it will shufle the fit in the same order benny 6.8.99
            [pop,pop_opt,fit,fitf,dis]=shuffle(pop,pop_opt,fit,fitf,dis);
        end	
    end
end
%save([comm.dirname,'\',comm.name,'_run_',num2str(count_run)],'pop_opt','pop','fitf1','fit1','dis')